@@ -19,7 +19,6 @@ from formencode import Invalid
 import formencode.validators as fev
 import sqlalchemy as sa
 import sqlalchemy.sql as sasql
-from webhelpers2.html.tags import link_to
 from werkzeug.datastructures import MultiDict
 
 from .extensions import gettext as _
@@ -347,13 +346,21 @@ class LinkColumnBase(Column):
                          has_subtotal, visible, group=group, **kwargs)
         self.link_label = link_label
 
+    def link_to(self, label, url, **kwargs):
+        return self.grid.html._render_jinja(
+            '<a href="{{url}}" {{- attrs|wg_attributes }}>{{label}}</a>',
+            url=url,
+            attrs=kwargs,
+            label=label
+        )
+
     def render_html(self, record, hah):
         url = self.create_url(record)
         if self.link_label is not None:
             label = self.link_label
         else:
             label = self.extract_and_format_data(record)
-        return link_to(label, url, **self.link_attrs)
+        return self.link_to(label, url, **self.link_attrs)
 
     def create_url(self, record):
         raise NotImplementedError('create_url() must be defined on a subclass')
@@ -393,23 +400,30 @@ class YesNoColumn(BoolColumn):
 class DateColumnBase(Column):
 
     def __init__(self, label, key_or_filter=None, key=None, can_sort=True,
-                 html_format=None, xls_width=None, xls_style=None, xls_num_format=None,
-                 render_in=_None, has_subtotal=False, visible=True, group=None, **kwargs):
+                 html_format=None, csv_format=None, xls_width=None, xls_style=None,
+                 xls_num_format=None, render_in=_None, has_subtotal=False, visible=True, group=None,
+                 **kwargs):
         super().__init__(label, key_or_filter, key, can_sort, xls_width,
                          xls_style, xls_num_format, render_in, has_subtotal,
                          visible, group=group, **kwargs)
         if html_format:
             self.html_format = html_format
 
+        if csv_format:
+            self.csv_format = csv_format
+
+    def _format_datetime(self, data, format):
+        # if we have an arrow date, allow html_format to use that functionality
+        if arrow and isinstance(data, arrow.Arrow):
+            if data.strftime(format) == format:
+                return data.format(format)
+        return data.strftime(format)
+
     def render_html(self, record, hah):
         data = self.extract_and_format_data(record)
         if not data:
             return data
-        # if we have an arrow date, allow html_format to use that functionality
-        if arrow and isinstance(data, arrow.Arrow):
-            if data.strftime(self.html_format) == self.html_format:
-                return data.format(self.html_format)
-        return data.strftime(self.html_format)
+        return self._format_datetime(data, self.html_format)
 
     def render_xls(self, record):
         data = self.extract_and_format_data(record)
@@ -431,9 +445,7 @@ class DateColumnBase(Column):
         data = self.extract_and_format_data(record)
         if not data:
             return data
-        if arrow and isinstance(data, arrow.Arrow):
-            data = data.datetime
-        return data
+        return self._format_datetime(data, self.csv_format)
 
     def xls_width_calc(self, value):
         if self.xls_width:
@@ -453,18 +465,21 @@ class DateColumnBase(Column):
 class DateColumn(DateColumnBase):
     # !!!: localize
     html_format = '%m/%d/%Y'
+    csv_format = '%Y-%m-%d'
     xls_num_format = 'm/dd/yyyy'
 
 
 class DateTimeColumn(DateColumnBase):
     # !!!: localize
     html_format = '%m/%d/%Y %I:%M %p'
+    csv_format = '%Y-%m-%d %H:%M:%S%z'
     xls_num_format = 'mm/dd/yyyy hh:mm am/pm'
 
 
 class TimeColumn(DateColumnBase):
     # !!!: localize
     html_format = '%I:%M %p'
+    csv_format = '%H:%M'
     xls_num_format = 'hh:mm am/pm'
 
 
@@ -588,6 +603,19 @@ class BaseGrid(six.with_metaclass(_DeclarativeMeta, object)):
     # filter at once
     enable_search = False
 
+    # List of joins to bring the query together for all columns. May have just the join object,
+    # or also conditions
+    # e.g. [Blog], ([Blog.category], ), or [(Blog, Blog.active == sa.true())]
+    # note: relationship attributes must be referenced within tuples, due to SQLAlchemy magic
+    query_joins = None
+    query_outer_joins = None
+    # Filter parameter(s) tuple to be used on the query
+    # note: relationship attributes must be referenced within tuples, due to SQLAlchemy magic
+    query_filter = None
+    # Parameter(s) tuple to be passed to order_by if sort options are not set on the grid
+    # note: relationship attributes must be referenced within tuples, due to SQLAlchemy magic
+    query_default_sort = None
+
     # Will ask for confirmation before exporting more than this many records.
     # Set to None to disable this check
     unconfirmed_export_limit = 10000
@@ -848,7 +876,21 @@ class BaseGrid(six.with_metaclass(_DeclarativeMeta, object)):
 
     def query_base(self, has_sort, has_filters):
         cols = [col.expr for col in self.columns if col.expr is not None]
-        return self.manager.sa_query(*cols)
+        query = self.manager.sa_query(*cols)
+
+        for join_terms in (tolist(self.query_joins) or tuple()):
+            query = query.join(*tolist(join_terms))
+
+        for join_terms in (tolist(self.query_outer_joins) or tuple()):
+            query = query.outerjoin(*tolist(join_terms))
+
+        if self.query_filter:
+            query = query.filter(*tolist(self.query_filter))
+
+        if not has_sort and self.query_default_sort is not None:
+            query = query.order_by(*tolist(self.query_default_sort))
+
+        return query
 
     def query_prep(self, query, has_sort, has_filters):
         return query
